==> qtjambi-qt3dinput-5.15.13-sources.jar: io/qt/qt3d/input/QActionInput.java <==
package io.qt.qt3d.input;


/**
 * <p>Stores Device and Buttons used to trigger an input event</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dinput-qactioninput.html">Qt3DInput::QActionInput</a></p>
 */
public class QActionInput extends io.qt.qt3d.input.QAbstractActionInput
{
    @io.qt.QtPropertyMember(enabled=false)
    private Object __rcSourceDevice = null;
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QActionInput.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qactioninput.html#buttonsChanged">Qt3DInput::QActionInput::buttonsChanged(QVector&lt;int&gt;)</a></p>
     */
    @io.qt.QtPropertyNotify(name="buttons")
    public final Signal1<java.util.List<java.lang.Integer>> buttonsChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qactioninput.html#sourceDeviceChanged">Qt3DInput::QActionInput::sourceDeviceChanged(Qt3DInput::QAbstractPhysicalDevice*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="sourceDevice")
    public final Signal1<io.qt.qt3d.input.QAbstractPhysicalDevice> sourceDeviceChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QActionInput(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QActionInput() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qactioninput.html#QActionInput">Qt3DInput::QActionInput::QActionInput(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QActionInput(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QActionInput instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qactioninput.html#buttons-prop">Qt3DInput::QActionInput::buttons()const</a></p>
     */
    @io.qt.QtPropertyReader(name="buttons")
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<java.lang.Integer> buttons(){
        return buttons_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<java.lang.Integer> buttons_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qactioninput.html#setButtons">Qt3DInput::QActionInput::setButtons(QVector&lt;int&gt;)</a></p>
     */
    @io.qt.QtPropertyWriter(name="buttons")
    public final void setButtons(java.util.Collection<java.lang.Integer> buttons){
        setButtons_native_cref_QVector(QtJambi_LibraryUtilities.internal.nativeId(this), buttons);
    }
    
    private native void setButtons_native_cref_QVector(long __this__nativeId, java.util.Collection<java.lang.Integer> buttons);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qactioninput.html#sourceDevice-prop">Qt3DInput::QActionInput::setSourceDevice(Qt3DInput::QAbstractPhysicalDevice*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="sourceDevice")
    public final void setSourceDevice(io.qt.qt3d.input.QAbstractPhysicalDevice sourceDevice){
        setSourceDevice_native_Qt3DInput_QAbstractPhysicalDevice_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(sourceDevice));
        __rcSourceDevice = sourceDevice;
    }
    
    private native void setSourceDevice_native_Qt3DInput_QAbstractPhysicalDevice_ptr(long __this__nativeId, long sourceDevice);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qactioninput.html#sourceDevice-prop">Qt3DInput::QActionInput::sourceDevice()const</a></p>
     */
    @io.qt.QtPropertyReader(name="sourceDevice")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.input.QAbstractPhysicalDevice sourceDevice(){
        return sourceDevice_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.input.QAbstractPhysicalDevice sourceDevice_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QActionInput(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QActionInput(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QActionInput instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3dinput-6.2.2-sources.jar: io/qt/qt3d/input/QActionInput.java <==
package io.qt.qt3d.input;


/**
 * <p>Stores Device and Buttons used to trigger an input event</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3dinput-qactioninput.html">Qt3DInput::QActionInput</a></p>
 */
public class QActionInput extends io.qt.qt3d.input.QAbstractActionInput
{
    @io.qt.QtPropertyMember(enabled=false)
    private Object __rcSourceDevice = null;
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QActionInput.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qactioninput.html#buttonsChanged">Qt3DInput::QActionInput::buttonsChanged(QList&lt;int&gt;)</a></p>
     */
    @io.qt.QtPropertyNotify(name="buttons")
    public final Signal1<java.util.List<java.lang.Integer>> buttonsChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qactioninput.html#sourceDeviceChanged">Qt3DInput::QActionInput::sourceDeviceChanged(Qt3DInput::QAbstractPhysicalDevice*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="sourceDevice")
    public final Signal1<io.qt.qt3d.input.QAbstractPhysicalDevice> sourceDeviceChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QActionInput(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QActionInput() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qactioninput.html#QActionInput">Qt3DInput::QActionInput::QActionInput(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QActionInput(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QActionInput instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qactioninput.html#buttons-prop">Qt3DInput::QActionInput::buttons()const</a></p>
     */
    @io.qt.QtPropertyReader(name="buttons")
    @io.qt.QtUninvokable
    public final io.qt.core.QList<java.lang.Integer> buttons(){
        return buttons_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<java.lang.Integer> buttons_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qactioninput.html#setButtons">Qt3DInput::QActionInput::setButtons(QList&lt;int&gt;)</a></p>
     */
    @io.qt.QtPropertyWriter(name="buttons")
    public final void setButtons(java.util.Collection<java.lang.Integer> buttons){
        setButtons_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), buttons);
    }
    
    private native void setButtons_native_cref_QList(long __this__nativeId, java.util.Collection<java.lang.Integer> buttons);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qactioninput.html#sourceDevice-prop">Qt3DInput::QActionInput::setSourceDevice(Qt3DInput::QAbstractPhysicalDevice*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="sourceDevice")
    public final void setSourceDevice(io.qt.qt3d.input.QAbstractPhysicalDevice sourceDevice){
        setSourceDevice_native_Qt3DInput_QAbstractPhysicalDevice_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(sourceDevice));
        __rcSourceDevice = sourceDevice;
    }
    
    private native void setSourceDevice_native_Qt3DInput_QAbstractPhysicalDevice_ptr(long __this__nativeId, long sourceDevice);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qactioninput.html#sourceDevice-prop">Qt3DInput::QActionInput::sourceDevice()const</a></p>
     */
    @io.qt.QtPropertyReader(name="sourceDevice")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.input.QAbstractPhysicalDevice sourceDevice(){
        return sourceDevice_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.input.QAbstractPhysicalDevice sourceDevice_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QActionInput(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QActionInput(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QActionInput instance, QDeclarativeConstructor constructor);
    
}
